@@ -55,7 +55,7 @@ class FirebaseAuthentication:
 
                 m = importlib.import_module(".".join(module[0: -1]))
                 register_user = getattr(m, module[-1])
-                user = register_user(user, decoded_token)
+                user = register_user(firebase_uid, decoded_token)
             else:
                 raise Exception("REGISTER_FIREBASE_USER setting is required.")
         return user
